package
Version:
v1.0.3
Opens a new window with list of versions in this module.
Published: Dec 19, 2025
License: MIT
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func SetVersion(version, commit, date string)
type DeployConfig struct {
Type string `mapstructure:"type"`
SiteID string `mapstructure:"siteID"`
SiteSource string `mapstructure:"siteSource"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.