package
Version:
v1.0.3
Opens a new window with list of versions in this module.
Published: Dec 19, 2025
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
GetOrDefault returns the value or default if empty
type Config struct {
PublicKey string `mapstructure:"public_key"`
SecretKey string `mapstructure:"secret_key"`
APIEndpoint string `mapstructure:"api_endpoint"`
StorageEndpoint string `mapstructure:"storage_endpoint"`
Region string `mapstructure:"region"`
}
Load reads configuration with the following precedence (highest to lowest):
- CLI flags
- Environment variables
- Profile from config file
- Default values
type ConfigFile struct {
Profiles map[string]Config `mapstructure:"profiles"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.